#
# spec file for package freecell-solver
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define soversion 0
%define libname libfreecell-solver
%bcond_with tests
Name:           freecell-solver
Version:        6.12.0
Release:        1.2
Summary:        A Freecell Solver
License:        MIT
URL:            https://fc-solve.shlomifish.org
Source0:        https://fc-solve.shlomifish.org/downloads/fc-solve/%{name}-%{version}.tar.xz
BuildRequires:  cmake >= 3.5
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  gmp-devel
BuildRequires:  gperf
BuildRequires:  perl-Template-Toolkit
BuildRequires:  pkgconfig
BuildRequires:  cmake(Rinutils)
BuildRequires:  perl(Moo)
BuildRequires:  perl(Path::Tiny)
BuildRequires:  pkgconfig(glib-2.0)
Requires:       python3-pysol-cards
Requires:       python3-random2
Requires:       python3-six
%if %{with tests}
BuildRequires:  python3-cffi
BuildRequires:  python3-pysol-cards
BuildRequires:  python3-random2
BuildRequires:  python3-six
BuildRequires:  perl(Task::FreecellSolver::Testing)
%endif

%description
Command line programs which can be used to solve Freecell and other card games.

%package -n %{name}-presets
Summary:        Freecell Solver presets
BuildArch:      noarch

%description -n %{name}-presets
Command line programs which can be used to solve Freecell and other card games.
This package contains the presets used to solve the games.

%package -n %{libname}%{soversion}
Summary:        Freecell Solver library
# This dependency is expected
Requires:       %{name}-presets = %{version}

%description -n %{libname}%{soversion}
This package contains the Freecell Solver library which can be used by some
programs to solves Freecell and other card games.

%package devel
Summary:        Freecell Solver development package
Requires:       %{libname}%{soversion} = %{version}

%description devel
Development package for the libfreecell-solver library

%prep
%autosetup -p1

# Unneeded 3rdparty module
rm -r rinutils

%build
%cmake -DBUILD_STATIC_LIBRARY:BOOL=FALSE \
       -DCMAKE_INSTALL_DOCDIR:STRING=%{_datadir}/doc/freecell-solver \
%if %{without tests}
       -DFCS_WITH_TEST_SUITE:BOOL=FALSE -D_PYTHON3=_PYTHON3-NOTFOUND \
%endif
       -DFCS_AVOID_TCMALLOC:BOOL=TRUE

%cmake_build

%if %{with tests}
%check
%ctest
%endif

%install
%cmake_install

# Fix the rpmlint warnings
rm -v %{buildroot}%{_datadir}/doc/freecell-solver/INSTALL
sed -i 's#%{_bindir}/env python3$#%{_bindir}/python3#' %{buildroot}%{_bindir}/*.py
sed -i 's#%{_bindir}/env python3$#%{_bindir}/python3#' %{buildroot}%{_bindir}/gen-multiple-pysol-layouts
sed -i '/^#!\/bin/d' %{buildroot}%{_datadir}/freecell-solver/presets/*.sh
%fdupes -s %{buildroot}%{_mandir}

%ldconfig_scriptlets -n %{libname}%{soversion}

%files -n %{libname}%{soversion}
%license COPYING.asciidoc
%{_libdir}/libfreecell-solver.so.*

%files devel
%{_includedir}/freecell-solver/
%{_libdir}/libfreecell-solver.so
%{_libdir}/pkgconfig/libfreecell-solver.pc

%files -n %{name}-presets
%{_datadir}/freecell-solver/

%files
%doc %{_datadir}/doc/freecell-solver/
%{_bindir}/dbm-fc-solver
%{_bindir}/depth-dbm-fc-solver
%{_bindir}/*freecell*
%{_bindir}/fc*
%{_bindir}/gen-multiple-pysol-layouts
%{_mandir}/man6/*

%changelog
* Tue Jul  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.12.0
  * Avoid packaging .tidyall.d
  * Renames to "global_instance" and clean-ups
* Fri Jun 28 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.10.0
  * Add experimental functions in FC_SOLVE_INSTANCE_PARAMS_QUERYING
  * Fewer compile-time / lint-time warnings
  * Convert some regular expressions from \d to [0-9]
* Mon Feb 26 2024 Christophe Marin <christophe@krop.fr>
- Set CMAKE_INSTALL_DOCDIR to work around incompatible changes
  added to macros.cmake.
* Wed Nov 30 2022 Christophe Marin <christophe@krop.fr>
- Update to 6.8.0
  * Workaround an ldd regression
  * OpenCL deal finder cleanups
  * Made the tests suite pass on more CMake options' configurations
  * Cleanups
* Thu Sep 22 2022 Christophe Giboudeaux <christophe@krop.fr>
- Add missing runtime requirements
* Thu Sep 22 2022 Dirk Müller <dmueller@suse.com>
- skip python dependencies as they're only for the testsuite
* Sat Oct 30 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.6.0
  * Ignore the FCS_SINGLE_HARD_THREAD and
    FCS_DISABLE_MULTI_NEXT_INSTS options while removing complexity
    from the source code.
  * Better rinutils bootstrap shim.
  * Silence some compiler warnings.
* Thu Apr 29 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 6.2.0
  * Fix run time errors
  * Add a more compact representation of zero-freecells deals
- New build requirement: python3-cffi
* Tue Sep  1 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.0.1
  * Fix a minor bug where the initial position could be
    traversed twice.
  * Add the +FCS_HARD_CODE_STATE_DEPTH_FIELD+ compile time option.
  * Code cleanups.
* Tue Jul 14 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.24.0. Changes since 5.22.1:
  * Add the "=all()" moves order specifier.
  * Add the FCS_ZERO_FREECELLS_MODE compile macro.
  * Update the compile time CMake descriptions for optimizing
    runtimes on more modern CPUs.
  * Remove support for the secondary hash value.
- Check the installed NEWS file for older changes.
* Fri Apr 19 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.6.0
  * Cleanups and optimisations
  * Add "--max-num-states" to the dbm solvers
  Check the NEWS.asciidoc file for the full list of changes.
* Wed Nov  7 2018 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.0.0
  * Add the gen-multiple-pysol-layouts executable to generate
    several numbered deals as separate files.
  * Rename the AsciiDoc documents
  * userland headers can now only be used with #include <freecell-solver/$headerName>
- Drop fix-rpmlint-errors.patch. Fixed upstream
* Thu May 24 2018 christophe@krop.fr
- Reduce dependencies. freecell-solver-presets
  doesn't need libfreecell-solver.
* Wed May 23 2018 christophe@krop.fr
- Initial Release.
